@@ -82,7 +82,7 @@ class _BucketBase(_Base):
         return -1 - low
 
     def minKey(self, key=_marker):
-        if key is _marker:
+        if key is _marker or key is None:
             return self._keys[0]
         key = self._to_key(key)
         index = self._search(key)
@@ -95,7 +95,7 @@ class _BucketBase(_Base):
             raise ValueError("no key satisfies the conditions")
 
     def maxKey(self, key=_marker):
-        if key is _marker:
+        if key is _marker or key is None:
             return self._keys[-1]
         key = self._to_key(key)
         index = self._search(key)
@@ -110,7 +110,7 @@ class _BucketBase(_Base):
 
     def _range(self, min=_marker, max=_marker,
                excludemin=False, excludemax=False):
-        if min is _marker:
+        if min is _marker or min is None:
             start = 0
             if excludemin:
                 start = 1
@@ -122,7 +122,7 @@ class _BucketBase(_Base):
                     start += 1
             else:
                 start = -start - 1
-        if max is _marker:
+        if max is _marker or max is None:
             end = len(self._keys)
             if excludemax:
                 end -= 1
@@ -207,12 +207,22 @@ class _SetIteration(object):
 
         return self
 
+_object_lt = getattr(object, '__lt__', _marker)
+
 def _no_default_comparison(key):
     # Enforce test that key has non-default comparison.
+    if key is None:
+        raise TypeError("Can't use None as a key")
+    if type(key) is object:
+        raise TypeError("Can't use object() as keys")
     lt = getattr(key, '__lt__', None)
     if lt is not None:
+        # CPython 3.x follows PEP 252, defining '__objclass__'
         if getattr(lt, '__objclass__', None) is object: #pragma NO COVER Py3k
             lt = None
+        # PyPy3 doesn't follow PEP 252, but defines '__func__'
+        elif getattr(lt, '__func__', None) is _object_lt: # pragma NO COVER
+            lt = None
     if (lt is None and
         getattr(key, '__cmp__', None) is None):
         raise TypeError("Can't use default __cmp__")
@@ -808,7 +818,7 @@ class _Tree(_Base):
         if not self._data:
             return ()
 
-        if min != _marker:
+        if min is not _marker and min is not None:
             min = self._to_key(min)
             bucket = self._findbucket(min)
         else:
@@ -826,7 +836,7 @@ class _Tree(_Base):
         return iter(self.keys())
 
     def minKey(self, min=_marker):
-        if min is _marker:
+        if min is _marker or min is None:
             bucket = self._firstbucket
         else:
             min = self._to_key(min)
@@ -839,7 +849,7 @@ class _Tree(_Base):
         data = self._data
         if not data:
             raise ValueError('empty tree')
-        if max is _marker:
+        if max is _marker or max is None:
             return data[-1].child.maxKey()
 
         max = self._to_key(max)
@@ -866,8 +876,13 @@ class _Tree(_Base):
 
         result = child._set(key, value, ifunset)
         grew = result[0]
-        if grew and child.size > child.MAX_SIZE:
-            self._grow(child, index)
+        if grew:
+            if child.__class__ is self.__class__:
+                max_size = self.max_internal_size
+            else:
+                max_size = self.max_leaf_size
+            if child.size > max_size:
+                self._grow(child, index)
         elif (grew is not None and
               child.__class__ is self._bucket_type and
               len(data) == 1 and
@@ -880,7 +895,7 @@ class _Tree(_Base):
         self._p_changed = True
         new_child = child._split()
         self._data.insert(index+1, _TreeItem(new_child.minKey(), new_child))
-        if len(self._data) > self.MAX_SIZE * 2:
+        if len(self._data) >= self.max_internal_size * 2:
             self._split_root()
 
     def _split_root(self):
